"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from kombo.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
    UnrecognizedStr,
)
from kombo.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Any, Dict, List, Literal, Union
from typing_extensions import Annotated, NotRequired, TypedDict


GetHrisEmployeesPositiveResponseGender = Union[
    Literal[
        "MALE",
        "FEMALE",
        "NON_BINARY",
        "NOT_SPECIFIED",
    ],
    UnrecognizedStr,
]


Ethnicity = Union[
    Literal[
        "WHITE",
        "ASIAN",
        "HISPANIC_LATINO",
        "HAWAIIAN",
        "NATIVE_AMERICAN",
        "BLACK_AFRICAN_AMERICAN",
        "MULTIPLE_ETHNICITIES",
        "DECLINE_TO_SPECIFY",
    ],
    UnrecognizedStr,
]


MaritalStatus = Union[
    Literal[
        "SINGLE",
        "MARRIED",
        "DOMESTIC_PARTNERSHIP",
        "WIDOWED",
        "DIVORCED",
        "SEPARATED",
        "NOT_MARRIED",
    ],
    UnrecognizedStr,
]


EmploymentStatus = Union[
    Literal[
        "ACTIVE",
        "PENDING",
        "INACTIVE",
        "LEAVE",
    ],
    UnrecognizedStr,
]


GetHrisEmployeesPositiveResponseEmploymentType = Union[
    Literal[
        "FULL_TIME",
        "PART_TIME",
        "CONTRACT",
        "INTERNSHIP",
        "FREELANCE",
        "WORKING_STUDENT",
        "APPRENTICESHIP",
        "TRAINING",
    ],
    UnrecognizedStr,
]


class HomeAddressTypedDict(TypedDict):
    r"""The employee’s home address."""

    city: NotRequired[Nullable[str]]
    country: NotRequired[Nullable[str]]
    r"""Contains the ISO2 country code if possible. If not, it contains the original value."""
    raw: NotRequired[Nullable[str]]
    r"""If we have address data, this is filled with the raw address string."""
    state: NotRequired[Nullable[str]]
    street_1: NotRequired[Nullable[str]]
    r"""If we can parse the address data, this field contains the first part of the street information."""
    street_2: NotRequired[Nullable[str]]
    zip_code: NotRequired[Nullable[str]]


class HomeAddress(BaseModel):
    r"""The employee’s home address."""

    city: OptionalNullable[str] = UNSET

    country: OptionalNullable[str] = UNSET
    r"""Contains the ISO2 country code if possible. If not, it contains the original value."""

    raw: OptionalNullable[str] = UNSET
    r"""If we have address data, this is filled with the raw address string."""

    state: OptionalNullable[str] = UNSET

    street_1: OptionalNullable[str] = UNSET
    r"""If we can parse the address data, this field contains the first part of the street information."""

    street_2: OptionalNullable[str] = UNSET

    zip_code: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["city", "country", "raw", "state", "street_1", "street_2", "zip_code"]
        )
        nullable_fields = set(
            ["city", "country", "raw", "state", "street_1", "street_2", "zip_code"]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


DomesticBankRoutingType = Literal[
    "GB_SORT_CODE",
    "DE_BANKLEITZAHL",
    "US_ABA_ROUTING_TRANSIT_NUMBER",
    "CA_ROUTING_NUMBER",
    "AU_BSB_CODE",
    "FR_RIB",
]
r"""Enum of the routing type, prefixed with the iso-3166-1-alpha-2 banks origin country. If there is uncertainty about the type, it will be set to null."""


class DomesticBankRoutingTypedDict(TypedDict):
    number: str
    r"""Bank routing number (e.g. DE Bankleitzahl, GB Sort Code, US ABA routing number, AU BSB code). This field is not formatted and therefore might contain delimiters (eg. 01-23-45)."""
    type: Nullable[DomesticBankRoutingType]
    r"""Enum of the routing type, prefixed with the iso-3166-1-alpha-2 banks origin country. If there is uncertainty about the type, it will be set to null."""


class DomesticBankRouting(BaseModel):
    number: str
    r"""Bank routing number (e.g. DE Bankleitzahl, GB Sort Code, US ABA routing number, AU BSB code). This field is not formatted and therefore might contain delimiters (eg. 01-23-45)."""

    type: Nullable[DomesticBankRoutingType]
    r"""Enum of the routing type, prefixed with the iso-3166-1-alpha-2 banks origin country. If there is uncertainty about the type, it will be set to null."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


class BankAccountTypedDict(TypedDict):
    iban: NotRequired[Nullable[str]]
    r"""The internationally unique IBAN identifying this account. If we detect a valid IBAN from the account number and this field would otherwise be empty, we will automatically populate this field."""
    bic: NotRequired[Nullable[str]]
    r"""The internationally unique BIC/SWIFT code identifying the bank behind this account. If we detect a valid BIC from the domestic bank routing number and this field would otherwise be empty, we will automatically populate this field."""
    account_number: NotRequired[Nullable[str]]
    r"""The bank-specific account number. Some companies use the account number field to put the IBAN here."""
    holder_name: NotRequired[Nullable[str]]
    r"""The name of the holder of this account."""
    bank_name: NotRequired[Nullable[str]]
    r"""The name of the bank behind this account."""
    domestic_bank_routing: NotRequired[Nullable[DomesticBankRoutingTypedDict]]


class BankAccount(BaseModel):
    iban: OptionalNullable[str] = UNSET
    r"""The internationally unique IBAN identifying this account. If we detect a valid IBAN from the account number and this field would otherwise be empty, we will automatically populate this field."""

    bic: OptionalNullable[str] = UNSET
    r"""The internationally unique BIC/SWIFT code identifying the bank behind this account. If we detect a valid BIC from the domestic bank routing number and this field would otherwise be empty, we will automatically populate this field."""

    account_number: OptionalNullable[str] = UNSET
    r"""The bank-specific account number. Some companies use the account number field to put the IBAN here."""

    holder_name: OptionalNullable[str] = UNSET
    r"""The name of the holder of this account."""

    bank_name: OptionalNullable[str] = UNSET
    r"""The name of the bank behind this account."""

    domestic_bank_routing: OptionalNullable[DomesticBankRouting] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "iban",
                "bic",
                "account_number",
                "holder_name",
                "bank_name",
                "domestic_bank_routing",
            ]
        )
        nullable_fields = set(
            [
                "iban",
                "bic",
                "account_number",
                "holder_name",
                "bank_name",
                "domestic_bank_routing",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


GetHrisEmployeesPositiveResponsePayPeriod = Union[
    Literal[
        "HOUR",
        "DAY",
        "WEEK",
        "TWO_WEEKS",
        "HALF_MONTH",
        "MONTH",
        "TWO_MONTHS",
        "QUARTER",
        "HALF_YEAR",
        "YEAR",
    ],
    UnrecognizedStr,
]


GetHrisEmployeesPositiveResponsePayFrequency = Union[
    Literal[
        "DAILY",
        "WEEKLY",
        "BIWEEKLY",
        "MONTHLY",
        "SEMIMONTHLY",
        "QUARTERLY",
        "SEMIANNUALLY",
        "ANNUALLY",
        "PRO_RATA",
    ],
    UnrecognizedStr,
]


EmploymentEmploymentType = Union[
    Literal[
        "FULL_TIME",
        "PART_TIME",
        "CONTRACT",
        "INTERNSHIP",
        "FREELANCE",
        "WORKING_STUDENT",
        "APPRENTICESHIP",
        "TRAINING",
    ],
    UnrecognizedStr,
]


class EmploymentTypedDict(TypedDict):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    employee_id: str
    r"""The Kombo ID of the employment’s employee. The ID can be used to retrieve the employee from the `get employees` endpoint."""
    job_title: Nullable[str]
    r"""This field can contain historic job titles. Please use the `job_title` field on the employee for the active job title of an employee."""
    pay_rate: Nullable[float]
    r"""The monetary amount paid to an employee."""
    pay_currency: Nullable[str]
    r"""The currency that the employee is paid in. Usually returned in [ISO 4217 currency codes](https://www.iso.org/iso-4217-currency-codes.html)."""
    effective_date: Nullable[datetime]
    r"""The date of when the employment started.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    custom_fields: Nullable[Dict[str, Any]]
    r"""A key-value store of fields not covered by the schema. [Read more](/custom-fields)"""
    pay_period: NotRequired[Nullable[GetHrisEmployeesPositiveResponsePayPeriod]]
    r"""The time interval which the `pay_rate` is describing.

    A `pay_rate` value of `12000` with a `pay_period` of `YEAR` would indicate that the employee receives 12000 over the course of a year. In rare cases where we can’t find a clear mapping, the original string is passed through.
    """
    pay_frequency: NotRequired[Nullable[GetHrisEmployeesPositiveResponsePayFrequency]]
    r"""The time interval at which the employee receives payment.

    A `pay_rate` of `12000`, with a `pay_period` of `YEAR`, and a `pay_frequency` of `MONTHLY` would indicate that the employee is paid 1000 every month. In rare cases where we can’t find a clear mapping, the original string is passed through.
    """
    employment_type: NotRequired[Nullable[EmploymentEmploymentType]]
    r"""The employee’s current employment type:

    - `FULL_TIME`: the employee is actively employed
    - `PART_TIME`: the employee is working only part of the usual working hours
    - `CONTRACT`: the employee is working temporarily under a contract
    - `INTERNSHIP`: the employee is working as an intern
    - `FREELANCE`: the employee is working as a freelancer
    - `WORKING_STUDENT`: the employee is working as a working student
    - `APPRENTICESHIP`: the employee is working in an apprenticeship
    - `TRAINING`: the employee is working in a training program

    In rare cases where we can’t find a clear mapping, the original string is passed through.
    """


class Employment(BaseModel):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    employee_id: str
    r"""The Kombo ID of the employment’s employee. The ID can be used to retrieve the employee from the `get employees` endpoint."""

    job_title: Nullable[str]
    r"""This field can contain historic job titles. Please use the `job_title` field on the employee for the active job title of an employee."""

    pay_rate: Nullable[float]
    r"""The monetary amount paid to an employee."""

    pay_currency: Nullable[str]
    r"""The currency that the employee is paid in. Usually returned in [ISO 4217 currency codes](https://www.iso.org/iso-4217-currency-codes.html)."""

    effective_date: Nullable[datetime]
    r"""The date of when the employment started.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    custom_fields: Nullable[Dict[str, Any]]
    r"""A key-value store of fields not covered by the schema. [Read more](/custom-fields)"""

    pay_period: OptionalNullable[GetHrisEmployeesPositiveResponsePayPeriod] = UNSET
    r"""The time interval which the `pay_rate` is describing.

    A `pay_rate` value of `12000` with a `pay_period` of `YEAR` would indicate that the employee receives 12000 over the course of a year. In rare cases where we can’t find a clear mapping, the original string is passed through.
    """

    pay_frequency: OptionalNullable[GetHrisEmployeesPositiveResponsePayFrequency] = (
        UNSET
    )
    r"""The time interval at which the employee receives payment.

    A `pay_rate` of `12000`, with a `pay_period` of `YEAR`, and a `pay_frequency` of `MONTHLY` would indicate that the employee is paid 1000 every month. In rare cases where we can’t find a clear mapping, the original string is passed through.
    """

    employment_type: OptionalNullable[EmploymentEmploymentType] = UNSET
    r"""The employee’s current employment type:

    - `FULL_TIME`: the employee is actively employed
    - `PART_TIME`: the employee is working only part of the usual working hours
    - `CONTRACT`: the employee is working temporarily under a contract
    - `INTERNSHIP`: the employee is working as an intern
    - `FREELANCE`: the employee is working as a freelancer
    - `WORKING_STUDENT`: the employee is working as a working student
    - `APPRENTICESHIP`: the employee is working in an apprenticeship
    - `TRAINING`: the employee is working in a training program

    In rare cases where we can’t find a clear mapping, the original string is passed through.
    """

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["pay_period", "pay_frequency", "employment_type"])
        nullable_fields = set(
            [
                "remote_id",
                "job_title",
                "pay_rate",
                "pay_period",
                "pay_frequency",
                "employment_type",
                "pay_currency",
                "effective_date",
                "remote_deleted_at",
                "custom_fields",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


GetHrisEmployeesPositiveResponseBalanceUnit = Literal[
    "HOURS",
    "DAYS",
]
r"""The time-unit of the balance."""


GetHrisEmployeesPositiveResponseUsedUnit = Literal[
    "HOURS",
    "DAYS",
]
r"""The time-unit of the used time."""


class TimeOffBalanceTypedDict(TypedDict):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    employee_id: str
    r"""The Kombo ID of the employee to which the balance belongs to. The ID can be used to retrieve the employee from the `get employees` endpoint."""
    type_id: str
    balance: Nullable[float]
    r"""The amount of time available to the employee."""
    balance_unit: Nullable[GetHrisEmployeesPositiveResponseBalanceUnit]
    r"""The time-unit of the balance."""
    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    used: Nullable[float]
    r"""The amount of time used by the employee."""
    used_unit: Nullable[GetHrisEmployeesPositiveResponseUsedUnit]
    r"""The time-unit of the used time."""


class TimeOffBalance(BaseModel):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    employee_id: str
    r"""The Kombo ID of the employee to which the balance belongs to. The ID can be used to retrieve the employee from the `get employees` endpoint."""

    type_id: str

    balance: Nullable[float]
    r"""The amount of time available to the employee."""

    balance_unit: Nullable[GetHrisEmployeesPositiveResponseBalanceUnit]
    r"""The time-unit of the balance."""

    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    used: Nullable[float]
    r"""The amount of time used by the employee."""

    used_unit: Nullable[GetHrisEmployeesPositiveResponseUsedUnit]
    r"""The time-unit of the used time."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


ManagerEmploymentStatus = Union[
    Literal[
        "ACTIVE",
        "PENDING",
        "INACTIVE",
        "LEAVE",
    ],
    UnrecognizedStr,
]


class ManagerTypedDict(TypedDict):
    first_name: Nullable[str]
    r"""The employee’s first name."""
    last_name: Nullable[str]
    r"""The employee’s last name."""
    display_full_name: Nullable[str]
    r"""The employee’s full name, including any middle names. Not all HR systems provide an explicit display name, so we recommend falling back to `first_name` and `last_name`."""
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    employee_number: Nullable[str]
    r"""The employee’s organization-internal employee number."""
    remote_id: str
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    termination_date: Nullable[datetime]
    r"""The date when the employment ends. Can be in the past or future.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    work_email: NotRequired[Nullable[str]]
    r"""The employee’s work email address. If the email address is invalid, we will set this to `null`."""
    employment_status: NotRequired[Nullable[ManagerEmploymentStatus]]
    r"""The employee’s current employment status:

    - `ACTIVE`: the employee is **actively employed**
    - `PENDING`: the employee is **not actively employed yet** (but they signed their contract or are part of an onboarding process)
    - `INACTIVE`: the employee is **not actively employed** anymore
    - `LEAVE`: the employee is still employed but **currently on leave** (note that not all HR systems support this status — use our absences API for detailed information)

    In rare cases where we can’t find a clear mapping, the original string is passed through.
    """


class Manager(BaseModel):
    first_name: Nullable[str]
    r"""The employee’s first name."""

    last_name: Nullable[str]
    r"""The employee’s last name."""

    display_full_name: Nullable[str]
    r"""The employee’s full name, including any middle names. Not all HR systems provide an explicit display name, so we recommend falling back to `first_name` and `last_name`."""

    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    employee_number: Nullable[str]
    r"""The employee’s organization-internal employee number."""

    remote_id: str
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    termination_date: Nullable[datetime]
    r"""The date when the employment ends. Can be in the past or future.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    work_email: OptionalNullable[str] = UNSET
    r"""The employee’s work email address. If the email address is invalid, we will set this to `null`."""

    employment_status: OptionalNullable[ManagerEmploymentStatus] = UNSET
    r"""The employee’s current employment status:

    - `ACTIVE`: the employee is **actively employed**
    - `PENDING`: the employee is **not actively employed yet** (but they signed their contract or are part of an onboarding process)
    - `INACTIVE`: the employee is **not actively employed** anymore
    - `LEAVE`: the employee is still employed but **currently on leave** (note that not all HR systems support this status — use our absences API for detailed information)

    In rare cases where we can’t find a clear mapping, the original string is passed through.
    """

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["work_email", "employment_status"])
        nullable_fields = set(
            [
                "first_name",
                "last_name",
                "display_full_name",
                "employee_number",
                "work_email",
                "employment_status",
                "termination_date",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


GetHrisEmployeesPositiveResponseGroupType = Literal[
    "DEPARTMENT",
    "TEAM",
    "COST_CENTER",
]
r"""Type of the group."""


class GetHrisEmployeesPositiveResponseGroupTypedDict(TypedDict):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    remote_id: str
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    name: Nullable[str]
    r"""The name of the group."""
    type: Nullable[GetHrisEmployeesPositiveResponseGroupType]
    r"""Type of the group."""


class GetHrisEmployeesPositiveResponseGroup(BaseModel):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    remote_id: str
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    name: Nullable[str]
    r"""The name of the group."""

    type: Nullable[GetHrisEmployeesPositiveResponseGroupType]
    r"""Type of the group."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


class LegalEntityAddressTypedDict(TypedDict):
    r"""The legal entity’s address."""

    city: NotRequired[Nullable[str]]
    country: NotRequired[Nullable[str]]
    r"""Contains the ISO2 country code if possible. If not, it contains the original value."""
    raw: NotRequired[Nullable[str]]
    r"""If we have address data, this is filled with the raw address string."""
    state: NotRequired[Nullable[str]]
    street_1: NotRequired[Nullable[str]]
    r"""If we can parse the address data, this field contains the first part of the street information."""
    street_2: NotRequired[Nullable[str]]
    zip_code: NotRequired[Nullable[str]]


class LegalEntityAddress(BaseModel):
    r"""The legal entity’s address."""

    city: OptionalNullable[str] = UNSET

    country: OptionalNullable[str] = UNSET
    r"""Contains the ISO2 country code if possible. If not, it contains the original value."""

    raw: OptionalNullable[str] = UNSET
    r"""If we have address data, this is filled with the raw address string."""

    state: OptionalNullable[str] = UNSET

    street_1: OptionalNullable[str] = UNSET
    r"""If we can parse the address data, this field contains the first part of the street information."""

    street_2: OptionalNullable[str] = UNSET

    zip_code: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["city", "country", "raw", "state", "street_1", "street_2", "zip_code"]
        )
        nullable_fields = set(
            ["city", "country", "raw", "state", "street_1", "street_2", "zip_code"]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


class GetHrisEmployeesPositiveResponseLegalEntityTypedDict(TypedDict):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    name: Nullable[str]
    r"""The legal entity’s name."""
    address: NotRequired[Nullable[LegalEntityAddressTypedDict]]
    r"""The legal entity’s address."""


class GetHrisEmployeesPositiveResponseLegalEntity(BaseModel):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    name: Nullable[str]
    r"""The legal entity’s name."""

    address: OptionalNullable[LegalEntityAddress] = UNSET
    r"""The legal entity’s address."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["address"])
        nullable_fields = set(["remote_id", "name", "address"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


class WorkLocationAddressTypedDict(TypedDict):
    r"""The work location’s address"""

    city: NotRequired[Nullable[str]]
    country: NotRequired[Nullable[str]]
    r"""Contains the ISO2 country code if possible. If not, it contains the original value."""
    raw: NotRequired[Nullable[str]]
    r"""If we have address data, this is filled with the raw address string."""
    state: NotRequired[Nullable[str]]
    street_1: NotRequired[Nullable[str]]
    r"""If we can parse the address data, this field contains the first part of the street information."""
    street_2: NotRequired[Nullable[str]]
    zip_code: NotRequired[Nullable[str]]


class WorkLocationAddress(BaseModel):
    r"""The work location’s address"""

    city: OptionalNullable[str] = UNSET

    country: OptionalNullable[str] = UNSET
    r"""Contains the ISO2 country code if possible. If not, it contains the original value."""

    raw: OptionalNullable[str] = UNSET
    r"""If we have address data, this is filled with the raw address string."""

    state: OptionalNullable[str] = UNSET

    street_1: OptionalNullable[str] = UNSET
    r"""If we can parse the address data, this field contains the first part of the street information."""

    street_2: OptionalNullable[str] = UNSET

    zip_code: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["city", "country", "raw", "state", "street_1", "street_2", "zip_code"]
        )
        nullable_fields = set(
            ["city", "country", "raw", "state", "street_1", "street_2", "zip_code"]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


class WorkLocationTypedDict(TypedDict):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    name: Nullable[str]
    r"""The work location’s name"""
    type: Nullable[str]
    r"""The work location’s type. A freeform string."""
    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    address: NotRequired[Nullable[WorkLocationAddressTypedDict]]
    r"""The work location’s address"""


class WorkLocation(BaseModel):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    name: Nullable[str]
    r"""The work location’s name"""

    type: Nullable[str]
    r"""The work location’s type. A freeform string."""

    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    address: OptionalNullable[WorkLocationAddress] = UNSET
    r"""The work location’s address"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["address"])
        nullable_fields = set(
            ["remote_id", "name", "address", "type", "remote_deleted_at"]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


class GetHrisEmployeesPositiveResponseResultTypedDict(TypedDict):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    remote_id: str
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    employee_number: Nullable[str]
    r"""The employee’s organization-internal employee number."""
    first_name: Nullable[str]
    r"""The employee’s first name."""
    last_name: Nullable[str]
    r"""The employee’s last name."""
    nationality: Nullable[str]
    r"""The employee’s nationality."""
    display_full_name: Nullable[str]
    r"""The employee’s full name, including any middle names. Not all HR systems provide an explicit display name, so we recommend falling back to `first_name` and `last_name`."""
    job_title: Nullable[str]
    r"""The employee’s job title."""
    mobile_phone_number: Nullable[str]
    r"""The employee’s mobile phone number."""
    ssn: Nullable[str]
    r"""The employee’s social security number"""
    tax_id: Nullable[str]
    r"""The employee’s tax ID."""
    weekly_hours: Nullable[float]
    r"""The employee’s weekly working hours."""
    avatar: Nullable[str]
    r"""URL to the employee’s avatar. This is either the raw URL from the HR system (in cases where it can be requested without short-lived authentication) _or_ a URL to a temporarily cached version of the file hosted by Kombo. Kombo will delete the cached file after its deletion in the source system."""
    work_location_id: Nullable[str]
    r"""The Kombo ID of the employee’s work location. The ID can be used to retrieve the work location from the `get work locations` endpoint."""
    legal_entity_id: Nullable[str]
    r"""The Kombo ID of the employee’s legal entity. The ID can be used to retrieve the legal entity from the `get legal entities` endpoint."""
    manager_id: Nullable[str]
    r"""The Kombo ID of the employee’s manager. The ID can be used to retrieve the manager from the `get employees` endpoint."""
    date_of_birth: Nullable[datetime]
    r"""The employee’s date of birth.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    start_date: Nullable[datetime]
    r"""The date the employee started working for the organization.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    termination_date: Nullable[datetime]
    r"""The date when the employment ends. Can be in the past or future.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    remote_created_at: Nullable[datetime]
    r"""The date and time the object was created in the remote system.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    custom_fields: Nullable[Dict[str, Any]]
    r"""A key-value store of fields not covered by the schema. [Read more](/custom-fields)"""
    employments: List[EmploymentTypedDict]
    time_off_balances: List[TimeOffBalanceTypedDict]
    manager: Nullable[ManagerTypedDict]
    groups: List[GetHrisEmployeesPositiveResponseGroupTypedDict]
    legal_entity: Nullable[GetHrisEmployeesPositiveResponseLegalEntityTypedDict]
    work_location: Nullable[WorkLocationTypedDict]
    work_email: NotRequired[Nullable[str]]
    r"""The employee’s work email address. If the email address is invalid, we will set this to `null`."""
    personal_email: NotRequired[Nullable[str]]
    r"""The employee’s personal email address. If the email address is invalid, we will set this to `null`."""
    gender: NotRequired[Nullable[GetHrisEmployeesPositiveResponseGender]]
    r"""The employee’s gender."""
    ethnicity: NotRequired[Nullable[Ethnicity]]
    r"""The employee’s ethnicity. In rare cases where we can’t find a clear mapping, the original string is passed through."""
    marital_status: NotRequired[Nullable[MaritalStatus]]
    r"""The employee’s current marital status. In rare cases where we can’t find a clear mapping, the original string is passed through."""
    employment_status: NotRequired[Nullable[EmploymentStatus]]
    r"""The employee’s current employment status:

    - `ACTIVE`: the employee is **actively employed**
    - `PENDING`: the employee is **not actively employed yet** (but they signed their contract or are part of an onboarding process)
    - `INACTIVE`: the employee is **not actively employed** anymore
    - `LEAVE`: the employee is still employed but **currently on leave** (note that not all HR systems support this status — use our absences API for detailed information)

    In rare cases where we can’t find a clear mapping, the original string is passed through.
    """
    employment_type: NotRequired[
        Nullable[GetHrisEmployeesPositiveResponseEmploymentType]
    ]
    r"""The employee’s current employment type:

    - `FULL_TIME`: the employee is actively employed
    - `PART_TIME`: the employee is working only part of the usual working hours
    - `CONTRACT`: the employee is working temporarily under a contract
    - `INTERNSHIP`: the employee is working as an intern
    - `FREELANCE`: the employee is working as a freelancer
    - `WORKING_STUDENT`: the employee is working as a working student
    - `APPRENTICESHIP`: the employee is working in an apprenticeship
    - `TRAINING`: the employee is working in a training program

    In rare cases where we can’t find a clear mapping, the original string is passed through.
    """
    home_address: NotRequired[Nullable[HomeAddressTypedDict]]
    r"""The employee’s home address."""
    bank_accounts: NotRequired[Nullable[List[BankAccountTypedDict]]]
    r"""The employee’s bank accounts."""


class GetHrisEmployeesPositiveResponseResult(BaseModel):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    remote_id: str
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    employee_number: Nullable[str]
    r"""The employee’s organization-internal employee number."""

    first_name: Nullable[str]
    r"""The employee’s first name."""

    last_name: Nullable[str]
    r"""The employee’s last name."""

    nationality: Nullable[str]
    r"""The employee’s nationality."""

    display_full_name: Nullable[str]
    r"""The employee’s full name, including any middle names. Not all HR systems provide an explicit display name, so we recommend falling back to `first_name` and `last_name`."""

    job_title: Nullable[str]
    r"""The employee’s job title."""

    mobile_phone_number: Nullable[str]
    r"""The employee’s mobile phone number."""

    ssn: Nullable[str]
    r"""The employee’s social security number"""

    tax_id: Nullable[str]
    r"""The employee’s tax ID."""

    weekly_hours: Nullable[float]
    r"""The employee’s weekly working hours."""

    avatar: Nullable[str]
    r"""URL to the employee’s avatar. This is either the raw URL from the HR system (in cases where it can be requested without short-lived authentication) _or_ a URL to a temporarily cached version of the file hosted by Kombo. Kombo will delete the cached file after its deletion in the source system."""

    work_location_id: Nullable[str]
    r"""The Kombo ID of the employee’s work location. The ID can be used to retrieve the work location from the `get work locations` endpoint."""

    legal_entity_id: Nullable[str]
    r"""The Kombo ID of the employee’s legal entity. The ID can be used to retrieve the legal entity from the `get legal entities` endpoint."""

    manager_id: Nullable[str]
    r"""The Kombo ID of the employee’s manager. The ID can be used to retrieve the manager from the `get employees` endpoint."""

    date_of_birth: Nullable[datetime]
    r"""The employee’s date of birth.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    start_date: Nullable[datetime]
    r"""The date the employee started working for the organization.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    termination_date: Nullable[datetime]
    r"""The date when the employment ends. Can be in the past or future.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    remote_created_at: Nullable[datetime]
    r"""The date and time the object was created in the remote system.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    custom_fields: Nullable[Dict[str, Any]]
    r"""A key-value store of fields not covered by the schema. [Read more](/custom-fields)"""

    employments: List[Employment]

    time_off_balances: List[TimeOffBalance]

    manager: Nullable[Manager]

    groups: List[GetHrisEmployeesPositiveResponseGroup]

    legal_entity: Nullable[GetHrisEmployeesPositiveResponseLegalEntity]

    work_location: Nullable[WorkLocation]

    work_email: OptionalNullable[str] = UNSET
    r"""The employee’s work email address. If the email address is invalid, we will set this to `null`."""

    personal_email: OptionalNullable[str] = UNSET
    r"""The employee’s personal email address. If the email address is invalid, we will set this to `null`."""

    gender: OptionalNullable[GetHrisEmployeesPositiveResponseGender] = UNSET
    r"""The employee’s gender."""

    ethnicity: OptionalNullable[Ethnicity] = UNSET
    r"""The employee’s ethnicity. In rare cases where we can’t find a clear mapping, the original string is passed through."""

    marital_status: OptionalNullable[MaritalStatus] = UNSET
    r"""The employee’s current marital status. In rare cases where we can’t find a clear mapping, the original string is passed through."""

    employment_status: OptionalNullable[EmploymentStatus] = UNSET
    r"""The employee’s current employment status:

    - `ACTIVE`: the employee is **actively employed**
    - `PENDING`: the employee is **not actively employed yet** (but they signed their contract or are part of an onboarding process)
    - `INACTIVE`: the employee is **not actively employed** anymore
    - `LEAVE`: the employee is still employed but **currently on leave** (note that not all HR systems support this status — use our absences API for detailed information)

    In rare cases where we can’t find a clear mapping, the original string is passed through.
    """

    employment_type: OptionalNullable[
        GetHrisEmployeesPositiveResponseEmploymentType
    ] = UNSET
    r"""The employee’s current employment type:

    - `FULL_TIME`: the employee is actively employed
    - `PART_TIME`: the employee is working only part of the usual working hours
    - `CONTRACT`: the employee is working temporarily under a contract
    - `INTERNSHIP`: the employee is working as an intern
    - `FREELANCE`: the employee is working as a freelancer
    - `WORKING_STUDENT`: the employee is working as a working student
    - `APPRENTICESHIP`: the employee is working in an apprenticeship
    - `TRAINING`: the employee is working in a training program

    In rare cases where we can’t find a clear mapping, the original string is passed through.
    """

    home_address: OptionalNullable[HomeAddress] = UNSET
    r"""The employee’s home address."""

    bank_accounts: OptionalNullable[List[BankAccount]] = UNSET
    r"""The employee’s bank accounts."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "work_email",
                "personal_email",
                "gender",
                "ethnicity",
                "marital_status",
                "employment_status",
                "employment_type",
                "home_address",
                "bank_accounts",
            ]
        )
        nullable_fields = set(
            [
                "employee_number",
                "first_name",
                "last_name",
                "nationality",
                "display_full_name",
                "job_title",
                "work_email",
                "personal_email",
                "mobile_phone_number",
                "ssn",
                "tax_id",
                "gender",
                "ethnicity",
                "marital_status",
                "employment_status",
                "employment_type",
                "weekly_hours",
                "avatar",
                "work_location_id",
                "legal_entity_id",
                "manager_id",
                "home_address",
                "bank_accounts",
                "date_of_birth",
                "start_date",
                "termination_date",
                "remote_created_at",
                "remote_deleted_at",
                "custom_fields",
                "manager",
                "legal_entity",
                "work_location",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


class GetHrisEmployeesPositiveResponseDataTypedDict(TypedDict):
    next: Nullable[str]
    r"""Cursor string that can be passed to the `cursor` query parameter to get the next page. If this is `null`, then there are no more pages."""
    results: List[GetHrisEmployeesPositiveResponseResultTypedDict]


class GetHrisEmployeesPositiveResponseData(BaseModel):
    next: Nullable[str]
    r"""Cursor string that can be passed to the `cursor` query parameter to get the next page. If this is `null`, then there are no more pages."""

    results: List[GetHrisEmployeesPositiveResponseResult]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


class GetHrisEmployeesPositiveResponseTypedDict(TypedDict):
    data: GetHrisEmployeesPositiveResponseDataTypedDict
    status: Literal["success"]


class GetHrisEmployeesPositiveResponse(BaseModel):
    data: GetHrisEmployeesPositiveResponseData

    STATUS: Annotated[
        Annotated[Literal["success"], AfterValidator(validate_const("success"))],
        pydantic.Field(alias="status"),
    ] = "success"


try:
    GetHrisEmployeesPositiveResponse.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .putintegrationsintegrationidenabledrequestbody import (
    PutIntegrationsIntegrationIDEnabledRequestBody,
    PutIntegrationsIntegrationIDEnabledRequestBodyTypedDict,
)
from kombo.types import BaseModel
from kombo.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class PutIntegrationsIntegrationIDEnabledRequestTypedDict(TypedDict):
    integration_id: str
    r"""PUT /integrations/:integration_id/enabled Parameter"""
    body: PutIntegrationsIntegrationIDEnabledRequestBodyTypedDict
    r"""PUT /integrations/:integration_id/enabled Request body"""


class PutIntegrationsIntegrationIDEnabledRequest(BaseModel):
    integration_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""PUT /integrations/:integration_id/enabled Parameter"""

    body: Annotated[
        PutIntegrationsIntegrationIDEnabledRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
    r"""PUT /integrations/:integration_id/enabled Request body"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .schema1 import Schema1, Schema1TypedDict
from .schema2_union_1 import Schema2Union1, Schema2Union1TypedDict
from kombo.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from kombo.utils import validate_const
import pydantic
from pydantic import Field, model_serializer
from pydantic.functional_validators import AfterValidator
from typing import List, Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


Schema1UnifiedKey8 = Literal[
    "first_name",
    "last_name",
    "date_of_birth",
    "gender",
    "home_address.city",
    "home_address.country",
    "home_address.state",
    "home_address.street_1",
    "home_address.street_2",
    "home_address.zip_code",
    "job_title",
    "legal_entity_id",
    "location_id",
    "mobile_phone_number",
    "home_phone_number",
    "nationality",
    "start_date",
    "work_email",
    "private_email",
    "yearly_salary",
]


class Schema1FileRestrictionsTypedDict(TypedDict):
    accepted_mime_types: List[str]
    max_file_size: NotRequired[Nullable[float]]


class Schema1FileRestrictions(BaseModel):
    accepted_mime_types: List[str]

    max_file_size: OptionalNullable[float] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["max_file_size"])
        nullable_fields = set(["max_file_size"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


class Schema1FileTypedDict(TypedDict):
    label: str
    required: bool
    file_restrictions: Schema1FileRestrictionsTypedDict
    description: NotRequired[Nullable[str]]
    unified_key: NotRequired[Nullable[Schema1UnifiedKey8]]
    type: Literal["file"]


class Schema1File(BaseModel):
    label: str

    required: bool

    file_restrictions: Schema1FileRestrictions

    description: OptionalNullable[str] = UNSET

    unified_key: OptionalNullable[Schema1UnifiedKey8] = UNSET

    TYPE: Annotated[
        Annotated[Literal["file"], AfterValidator(validate_const("file"))],
        pydantic.Field(alias="type"),
    ] = "file"

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["description", "unified_key"])
        nullable_fields = set(["description", "unified_key"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


Schema1UnifiedKey7 = Literal[
    "first_name",
    "last_name",
    "date_of_birth",
    "gender",
    "home_address.city",
    "home_address.country",
    "home_address.state",
    "home_address.street_1",
    "home_address.street_2",
    "home_address.zip_code",
    "job_title",
    "legal_entity_id",
    "location_id",
    "mobile_phone_number",
    "home_phone_number",
    "nationality",
    "start_date",
    "work_email",
    "private_email",
    "yearly_salary",
]


class Schema1Array1TypedDict(TypedDict):
    label: str
    required: bool
    item_type: Schema2Union1TypedDict
    description: NotRequired[Nullable[str]]
    unified_key: NotRequired[Nullable[Schema1UnifiedKey7]]
    type: Literal["array"]
    min_items: NotRequired[Nullable[float]]
    max_items: NotRequired[Nullable[float]]


class Schema1Array1(BaseModel):
    label: str

    required: bool

    item_type: Schema2Union1

    description: OptionalNullable[str] = UNSET

    unified_key: OptionalNullable[Schema1UnifiedKey7] = UNSET

    TYPE: Annotated[
        Annotated[Literal["array"], AfterValidator(validate_const("array"))],
        pydantic.Field(alias="type"),
    ] = "array"

    min_items: OptionalNullable[float] = UNSET

    max_items: OptionalNullable[float] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["description", "unified_key", "min_items", "max_items"])
        nullable_fields = set(["description", "unified_key", "min_items", "max_items"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


Schema1UnifiedKey6 = Literal[
    "first_name",
    "last_name",
    "date_of_birth",
    "gender",
    "home_address.city",
    "home_address.country",
    "home_address.state",
    "home_address.street_1",
    "home_address.street_2",
    "home_address.zip_code",
    "job_title",
    "legal_entity_id",
    "location_id",
    "mobile_phone_number",
    "home_phone_number",
    "nationality",
    "start_date",
    "work_email",
    "private_email",
    "yearly_salary",
]


class Schema1ObjectTypedDict(TypedDict):
    label: str
    required: bool
    properties: Schema1TypedDict
    description: NotRequired[Nullable[str]]
    unified_key: NotRequired[Nullable[Schema1UnifiedKey6]]
    type: Literal["object"]


class Schema1Object(BaseModel):
    label: str

    required: bool

    properties: Schema1

    description: OptionalNullable[str] = UNSET

    unified_key: OptionalNullable[Schema1UnifiedKey6] = UNSET

    TYPE: Annotated[
        Annotated[Literal["object"], AfterValidator(validate_const("object"))],
        pydantic.Field(alias="type"),
    ] = "object"

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["description", "unified_key"])
        nullable_fields = set(["description", "unified_key"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


Schema1UnifiedKey5 = Literal[
    "first_name",
    "last_name",
    "date_of_birth",
    "gender",
    "home_address.city",
    "home_address.country",
    "home_address.state",
    "home_address.street_1",
    "home_address.street_2",
    "home_address.zip_code",
    "job_title",
    "legal_entity_id",
    "location_id",
    "mobile_phone_number",
    "home_phone_number",
    "nationality",
    "start_date",
    "work_email",
    "private_email",
    "yearly_salary",
]


class Schema1CheckboxTypedDict(TypedDict):
    label: str
    required: bool
    description: NotRequired[Nullable[str]]
    unified_key: NotRequired[Nullable[Schema1UnifiedKey5]]
    type: Literal["checkbox"]


class Schema1Checkbox(BaseModel):
    label: str

    required: bool

    description: OptionalNullable[str] = UNSET

    unified_key: OptionalNullable[Schema1UnifiedKey5] = UNSET

    TYPE: Annotated[
        Annotated[Literal["checkbox"], AfterValidator(validate_const("checkbox"))],
        pydantic.Field(alias="type"),
    ] = "checkbox"

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["description", "unified_key"])
        nullable_fields = set(["description", "unified_key"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


class Schema1OptionsReferenced2TypedDict(TypedDict):
    link: str
    type: Literal["referenced"]


class Schema1OptionsReferenced2(BaseModel):
    link: str

    TYPE: Annotated[
        Annotated[Literal["referenced"], AfterValidator(validate_const("referenced"))],
        pydantic.Field(alias="type"),
    ] = "referenced"


Schema1RemoteID2TypedDict = TypeAliasType(
    "Schema1RemoteID2TypedDict", Union[str, float]
)


Schema1RemoteID2 = TypeAliasType("Schema1RemoteID2", Union[str, float])


class Schema1Entry2TypedDict(TypedDict):
    id: str
    label: str
    remote_id: Schema1RemoteID2TypedDict
    unified_value: NotRequired[str]


class Schema1Entry2(BaseModel):
    id: str

    label: str

    remote_id: Schema1RemoteID2

    unified_value: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["unified_value"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class Schema1OptionsInline2TypedDict(TypedDict):
    entries: List[Schema1Entry2TypedDict]
    type: Literal["inline"]


class Schema1OptionsInline2(BaseModel):
    entries: List[Schema1Entry2]

    TYPE: Annotated[
        Annotated[Literal["inline"], AfterValidator(validate_const("inline"))],
        pydantic.Field(alias="type"),
    ] = "inline"


Schema1OptionsUnion2TypedDict = TypeAliasType(
    "Schema1OptionsUnion2TypedDict",
    Union[Schema1OptionsInline2TypedDict, Schema1OptionsReferenced2TypedDict],
)


Schema1OptionsUnion2 = Annotated[
    Union[Schema1OptionsInline2, Schema1OptionsReferenced2], Field(discriminator="TYPE")
]


class Schema1MultiSelectTypedDict(TypedDict):
    label: str
    required: bool
    options: Schema1OptionsUnion2TypedDict
    description: NotRequired[Nullable[str]]
    unified_key: NotRequired[Nullable[str]]
    type: Literal["multi_select"]
    min_items: NotRequired[Nullable[float]]
    max_items: NotRequired[Nullable[float]]


class Schema1MultiSelect(BaseModel):
    label: str

    required: bool

    options: Schema1OptionsUnion2

    description: OptionalNullable[str] = UNSET

    unified_key: OptionalNullable[str] = UNSET

    TYPE: Annotated[
        Annotated[
            Literal["multi_select"], AfterValidator(validate_const("multi_select"))
        ],
        pydantic.Field(alias="type"),
    ] = "multi_select"

    min_items: OptionalNullable[float] = UNSET

    max_items: OptionalNullable[float] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["description", "unified_key", "min_items", "max_items"])
        nullable_fields = set(["description", "unified_key", "min_items", "max_items"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


Schema1UnifiedKey4 = Literal[
    "first_name",
    "last_name",
    "date_of_birth",
    "gender",
    "home_address.city",
    "home_address.country",
    "home_address.state",
    "home_address.street_1",
    "home_address.street_2",
    "home_address.zip_code",
    "job_title",
    "legal_entity_id",
    "location_id",
    "mobile_phone_number",
    "home_phone_number",
    "nationality",
    "start_date",
    "work_email",
    "private_email",
    "yearly_salary",
]


class Schema1OptionsReferenced1TypedDict(TypedDict):
    link: str
    type: Literal["referenced"]


class Schema1OptionsReferenced1(BaseModel):
    link: str

    TYPE: Annotated[
        Annotated[Literal["referenced"], AfterValidator(validate_const("referenced"))],
        pydantic.Field(alias="type"),
    ] = "referenced"


Schema1RemoteID1TypedDict = TypeAliasType(
    "Schema1RemoteID1TypedDict", Union[str, float]
)


Schema1RemoteID1 = TypeAliasType("Schema1RemoteID1", Union[str, float])


class Schema1Entry1TypedDict(TypedDict):
    id: str
    label: str
    remote_id: Schema1RemoteID1TypedDict
    unified_value: NotRequired[str]


class Schema1Entry1(BaseModel):
    id: str

    label: str

    remote_id: Schema1RemoteID1

    unified_value: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["unified_value"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class Schema1OptionsInline1TypedDict(TypedDict):
    entries: List[Schema1Entry1TypedDict]
    type: Literal["inline"]


class Schema1OptionsInline1(BaseModel):
    entries: List[Schema1Entry1]

    TYPE: Annotated[
        Annotated[Literal["inline"], AfterValidator(validate_const("inline"))],
        pydantic.Field(alias="type"),
    ] = "inline"


Schema1OptionsUnion1TypedDict = TypeAliasType(
    "Schema1OptionsUnion1TypedDict",
    Union[Schema1OptionsInline1TypedDict, Schema1OptionsReferenced1TypedDict],
)


Schema1OptionsUnion1 = Annotated[
    Union[Schema1OptionsInline1, Schema1OptionsReferenced1], Field(discriminator="TYPE")
]


class Schema1SingleSelectTypedDict(TypedDict):
    label: str
    required: bool
    options: Schema1OptionsUnion1TypedDict
    description: NotRequired[Nullable[str]]
    unified_key: NotRequired[Nullable[Schema1UnifiedKey4]]
    type: Literal["single_select"]


class Schema1SingleSelect(BaseModel):
    label: str

    required: bool

    options: Schema1OptionsUnion1

    description: OptionalNullable[str] = UNSET

    unified_key: OptionalNullable[Schema1UnifiedKey4] = UNSET

    TYPE: Annotated[
        Annotated[
            Literal["single_select"], AfterValidator(validate_const("single_select"))
        ],
        pydantic.Field(alias="type"),
    ] = "single_select"

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["description", "unified_key"])
        nullable_fields = set(["description", "unified_key"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


Schema1UnifiedKey3 = Literal[
    "first_name",
    "last_name",
    "date_of_birth",
    "gender",
    "home_address.city",
    "home_address.country",
    "home_address.state",
    "home_address.street_1",
    "home_address.street_2",
    "home_address.zip_code",
    "job_title",
    "legal_entity_id",
    "location_id",
    "mobile_phone_number",
    "home_phone_number",
    "nationality",
    "start_date",
    "work_email",
    "private_email",
    "yearly_salary",
]


class Schema1DateTypedDict(TypedDict):
    label: str
    required: bool
    description: NotRequired[Nullable[str]]
    unified_key: NotRequired[Nullable[Schema1UnifiedKey3]]
    type: Literal["date"]


class Schema1Date(BaseModel):
    label: str

    required: bool

    description: OptionalNullable[str] = UNSET

    unified_key: OptionalNullable[Schema1UnifiedKey3] = UNSET

    TYPE: Annotated[
        Annotated[Literal["date"], AfterValidator(validate_const("date"))],
        pydantic.Field(alias="type"),
    ] = "date"

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["description", "unified_key"])
        nullable_fields = set(["description", "unified_key"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


Schema1UnifiedKey2 = Literal[
    "first_name",
    "last_name",
    "date_of_birth",
    "gender",
    "home_address.city",
    "home_address.country",
    "home_address.state",
    "home_address.street_1",
    "home_address.street_2",
    "home_address.zip_code",
    "job_title",
    "legal_entity_id",
    "location_id",
    "mobile_phone_number",
    "home_phone_number",
    "nationality",
    "start_date",
    "work_email",
    "private_email",
    "yearly_salary",
]


class Schema1NumberTypedDict(TypedDict):
    label: str
    required: bool
    description: NotRequired[Nullable[str]]
    unified_key: NotRequired[Nullable[Schema1UnifiedKey2]]
    type: Literal["number"]
    min: NotRequired[Nullable[float]]
    max: NotRequired[Nullable[float]]


class Schema1Number(BaseModel):
    label: str

    required: bool

    description: OptionalNullable[str] = UNSET

    unified_key: OptionalNullable[Schema1UnifiedKey2] = UNSET

    TYPE: Annotated[
        Annotated[Literal["number"], AfterValidator(validate_const("number"))],
        pydantic.Field(alias="type"),
    ] = "number"

    min: OptionalNullable[float] = UNSET

    max: OptionalNullable[float] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["description", "unified_key", "min", "max"])
        nullable_fields = set(["description", "unified_key", "min", "max"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


Schema1UnifiedKey1 = Literal[
    "first_name",
    "last_name",
    "date_of_birth",
    "gender",
    "home_address.city",
    "home_address.country",
    "home_address.state",
    "home_address.street_1",
    "home_address.street_2",
    "home_address.zip_code",
    "job_title",
    "legal_entity_id",
    "location_id",
    "mobile_phone_number",
    "home_phone_number",
    "nationality",
    "start_date",
    "work_email",
    "private_email",
    "yearly_salary",
]


class Schema1TextTypedDict(TypedDict):
    label: str
    required: bool
    description: NotRequired[Nullable[str]]
    unified_key: NotRequired[Nullable[Schema1UnifiedKey1]]
    type: Literal["text"]
    min_length: NotRequired[Nullable[float]]
    max_length: NotRequired[Nullable[float]]
    reg_exp: NotRequired[Nullable[str]]


class Schema1Text(BaseModel):
    label: str

    required: bool

    description: OptionalNullable[str] = UNSET

    unified_key: OptionalNullable[Schema1UnifiedKey1] = UNSET

    TYPE: Annotated[
        Annotated[Literal["text"], AfterValidator(validate_const("text"))],
        pydantic.Field(alias="type"),
    ] = "text"

    min_length: OptionalNullable[float] = UNSET

    max_length: OptionalNullable[float] = UNSET

    reg_exp: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["description", "unified_key", "min_length", "max_length", "reg_exp"]
        )
        nullable_fields = set(
            ["description", "unified_key", "min_length", "max_length", "reg_exp"]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


Schema1Union1TypedDict = TypeAliasType(
    "Schema1Union1TypedDict",
    Union[
        Schema1DateTypedDict,
        Schema1CheckboxTypedDict,
        Schema1SingleSelectTypedDict,
        Schema1ObjectTypedDict,
        Schema1FileTypedDict,
        Schema1NumberTypedDict,
        Schema1TextTypedDict,
        Schema1MultiSelectTypedDict,
        Schema1Array1TypedDict,
    ],
)


Schema1Union1 = Annotated[
    Union[
        Schema1Text,
        Schema1Number,
        Schema1Date,
        Schema1SingleSelect,
        Schema1MultiSelect,
        Schema1Checkbox,
        Schema1Object,
        Schema1Array1,
        Schema1File,
    ],
    Field(discriminator="TYPE"),
]


try:
    Schema1File.model_rebuild()
except NameError:
    pass
try:
    Schema1Array1.model_rebuild()
except NameError:
    pass
try:
    Schema1Object.model_rebuild()
except NameError:
    pass
try:
    Schema1Checkbox.model_rebuild()
except NameError:
    pass
try:
    Schema1OptionsReferenced2.model_rebuild()
except NameError:
    pass
try:
    Schema1OptionsInline2.model_rebuild()
except NameError:
    pass
try:
    Schema1MultiSelect.model_rebuild()
except NameError:
    pass
try:
    Schema1OptionsReferenced1.model_rebuild()
except NameError:
    pass
try:
    Schema1OptionsInline1.model_rebuild()
except NameError:
    pass
try:
    Schema1SingleSelect.model_rebuild()
except NameError:
    pass
try:
    Schema1Date.model_rebuild()
except NameError:
    pass
try:
    Schema1Number.model_rebuild()
except NameError:
    pass
try:
    Schema1Text.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from kombo.types import BaseModel, Nullable, UNSET_SENTINEL
from kombo.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Any, Dict, List, Literal
from typing_extensions import Annotated, TypedDict


ModelType = Literal[
    "JOB",
    "POSITION",
    "REQUISITION",
]
r"""The remote model type of the record. Possible values are \"JOB\", \"POSITION\" or \"REQUISITION\". We recommend that users of our `create employee` endpoint ask the customer whether they want to hire into positions or requisitions."""


GetHrisStaffingEntitiesPositiveResponseStatus = Literal[
    "OPEN_LIMITED",
    "OPEN_UNLIMITED",
    "PENDING",
    "FROZEN",
    "FILLED",
    "CLOSED",
]
r"""The status of the staffing entity.
OPEN_LIMITED: The staffing entity is open and has a limited number of openings. Refer to the `number_of_openings` field to get the number of openings.
OPEN_UNLIMITED: The staffing entity is open and has an unlimited number of openings. Some enterprise systems refer to this as \"Evergreen\".
PENDING: The staffing entity is pending approval or is waiting to be published.
FROZEN: The staffing entity is frozen (hiring freeze) and does not accept applications/hires.
FILLED: The staffing entity is filled (to its maximum capacity) and not available for new hires.
CLOSED: The staffing entity is closed and not available for new hires.
"""


GetHrisStaffingEntitiesPositiveResponseUnifiedType = Literal[
    "FULL_TIME",
    "PART_TIME",
    "CONTRACT",
    "INTERNSHIP",
    "FREELANCE",
    "WORKING_STUDENT",
    "APPRENTICESHIP",
    "TRAINING",
]
r"""The unified type, how Kombo categorize this label."""


class GetHrisStaffingEntitiesPositiveResponseEmploymentTypeTypedDict(TypedDict):
    remote_label: str
    r"""The label of the employment type how it appears in the remote system."""
    unified_type: Nullable[GetHrisStaffingEntitiesPositiveResponseUnifiedType]
    r"""The unified type, how Kombo categorize this label."""


class GetHrisStaffingEntitiesPositiveResponseEmploymentType(BaseModel):
    remote_label: str
    r"""The label of the employment type how it appears in the remote system."""

    unified_type: Nullable[GetHrisStaffingEntitiesPositiveResponseUnifiedType]
    r"""The unified type, how Kombo categorize this label."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


class GetHrisStaffingEntitiesPositiveResponseLocationTypedDict(TypedDict):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    name: Nullable[str]
    r"""The work location’s name"""
    type: Nullable[str]
    r"""The work location’s type. A freeform string."""


class GetHrisStaffingEntitiesPositiveResponseLocation(BaseModel):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    name: Nullable[str]
    r"""The work location’s name"""

    type: Nullable[str]
    r"""The work location’s type. A freeform string."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


class GetHrisStaffingEntitiesPositiveResponseLegalEntityTypedDict(TypedDict):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    name: Nullable[str]
    r"""The legal entity’s name."""


class GetHrisStaffingEntitiesPositiveResponseLegalEntity(BaseModel):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    name: Nullable[str]
    r"""The legal entity’s name."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


GetHrisStaffingEntitiesPositiveResponseType = Literal[
    "DEPARTMENT",
    "TEAM",
    "COST_CENTER",
]
r"""Type of the group."""


class GetHrisStaffingEntitiesPositiveResponseGroupTypedDict(TypedDict):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    remote_id: str
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    name: Nullable[str]
    r"""The name of the group."""
    type: Nullable[GetHrisStaffingEntitiesPositiveResponseType]
    r"""Type of the group."""


class GetHrisStaffingEntitiesPositiveResponseGroup(BaseModel):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    remote_id: str
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    name: Nullable[str]
    r"""The name of the group."""

    type: Nullable[GetHrisStaffingEntitiesPositiveResponseType]
    r"""Type of the group."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


class GetHrisStaffingEntitiesPositiveResponseResultTypedDict(TypedDict):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    remote_id: str
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    name: Nullable[str]
    r"""The name/title of the staffing entity."""
    model_type: Nullable[ModelType]
    r"""The remote model type of the record. Possible values are \"JOB\", \"POSITION\" or \"REQUISITION\". We recommend that users of our `create employee` endpoint ask the customer whether they want to hire into positions or requisitions."""
    description: Nullable[str]
    r"""A text description of the staffing entity — typically covering responsibilities, requirements, and scope. Commonly referred to as the \"job description\" in HRIS systems. May contain HTML, depending on the source system."""
    status: Nullable[GetHrisStaffingEntitiesPositiveResponseStatus]
    r"""The status of the staffing entity.
    OPEN_LIMITED: The staffing entity is open and has a limited number of openings. Refer to the `number_of_openings` field to get the number of openings.
    OPEN_UNLIMITED: The staffing entity is open and has an unlimited number of openings. Some enterprise systems refer to this as \"Evergreen\".
    PENDING: The staffing entity is pending approval or is waiting to be published.
    FROZEN: The staffing entity is frozen (hiring freeze) and does not accept applications/hires.
    FILLED: The staffing entity is filled (to its maximum capacity) and not available for new hires.
    CLOSED: The staffing entity is closed and not available for new hires.
    """
    employment_types: Nullable[
        List[GetHrisStaffingEntitiesPositiveResponseEmploymentTypeTypedDict]
    ]
    r"""The employment types available for/used by the staffing entity. Use the `remote_label` for display in your UI as it is consistent with the language of the remote system. Use the `unified_type` for internal categorization as it is unified across all tools."""
    number_of_openings: Nullable[float]
    r"""The number of openings for the staffing entity. Only meaningful for staffing entities with the status \"OPEN_LIMITED\"."""
    parent_id: Nullable[str]
    r"""The Kombo ID of the staffing entity’s parent. Usually it’s the position/job that was used to create the requisition. The ID can be used to retrieve the parent staffing entity from the `get staffing entity` endpoint."""
    remote_url: Nullable[str]
    r"""URL to the staffing entity in the HRIS system. Use this to implement backlinks into the HRIS/Enterprise System."""
    remote_created_at: Nullable[datetime]
    r"""The date and time the object was created in the remote system.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    remote_updated_at: Nullable[datetime]
    r"""A timestamp retrieved from the remote system, describing when the resource was last updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    custom_fields: Nullable[Dict[str, Any]]
    r"""A key-value store of fields not covered by the schema. [Read more](/custom-fields)"""
    locations: List[GetHrisStaffingEntitiesPositiveResponseLocationTypedDict]
    r"""The physical work locations associated with this staffing entity. A position or requisition can be linked to one or more offices or sites where the role is to be filled."""
    legal_entities: List[GetHrisStaffingEntitiesPositiveResponseLegalEntityTypedDict]
    r"""The legal entities (companies or sub-companies) associated with this staffing entity. Indicates which employing entities within the organization the position or requisition belongs to."""
    groups: List[GetHrisStaffingEntitiesPositiveResponseGroupTypedDict]
    r"""The organizational groups (such as departments, teams, or cost centers) associated with this staffing entity."""


class GetHrisStaffingEntitiesPositiveResponseResult(BaseModel):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    remote_id: str
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    name: Nullable[str]
    r"""The name/title of the staffing entity."""

    model_type: Nullable[ModelType]
    r"""The remote model type of the record. Possible values are \"JOB\", \"POSITION\" or \"REQUISITION\". We recommend that users of our `create employee` endpoint ask the customer whether they want to hire into positions or requisitions."""

    description: Nullable[str]
    r"""A text description of the staffing entity — typically covering responsibilities, requirements, and scope. Commonly referred to as the \"job description\" in HRIS systems. May contain HTML, depending on the source system."""

    status: Nullable[GetHrisStaffingEntitiesPositiveResponseStatus]
    r"""The status of the staffing entity.
    OPEN_LIMITED: The staffing entity is open and has a limited number of openings. Refer to the `number_of_openings` field to get the number of openings.
    OPEN_UNLIMITED: The staffing entity is open and has an unlimited number of openings. Some enterprise systems refer to this as \"Evergreen\".
    PENDING: The staffing entity is pending approval or is waiting to be published.
    FROZEN: The staffing entity is frozen (hiring freeze) and does not accept applications/hires.
    FILLED: The staffing entity is filled (to its maximum capacity) and not available for new hires.
    CLOSED: The staffing entity is closed and not available for new hires.
    """

    employment_types: Nullable[
        List[GetHrisStaffingEntitiesPositiveResponseEmploymentType]
    ]
    r"""The employment types available for/used by the staffing entity. Use the `remote_label` for display in your UI as it is consistent with the language of the remote system. Use the `unified_type` for internal categorization as it is unified across all tools."""

    number_of_openings: Nullable[float]
    r"""The number of openings for the staffing entity. Only meaningful for staffing entities with the status \"OPEN_LIMITED\"."""

    parent_id: Nullable[str]
    r"""The Kombo ID of the staffing entity’s parent. Usually it’s the position/job that was used to create the requisition. The ID can be used to retrieve the parent staffing entity from the `get staffing entity` endpoint."""

    remote_url: Nullable[str]
    r"""URL to the staffing entity in the HRIS system. Use this to implement backlinks into the HRIS/Enterprise System."""

    remote_created_at: Nullable[datetime]
    r"""The date and time the object was created in the remote system.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    remote_updated_at: Nullable[datetime]
    r"""A timestamp retrieved from the remote system, describing when the resource was last updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    custom_fields: Nullable[Dict[str, Any]]
    r"""A key-value store of fields not covered by the schema. [Read more](/custom-fields)"""

    locations: List[GetHrisStaffingEntitiesPositiveResponseLocation]
    r"""The physical work locations associated with this staffing entity. A position or requisition can be linked to one or more offices or sites where the role is to be filled."""

    legal_entities: List[GetHrisStaffingEntitiesPositiveResponseLegalEntity]
    r"""The legal entities (companies or sub-companies) associated with this staffing entity. Indicates which employing entities within the organization the position or requisition belongs to."""

    groups: List[GetHrisStaffingEntitiesPositiveResponseGroup]
    r"""The organizational groups (such as departments, teams, or cost centers) associated with this staffing entity."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


class GetHrisStaffingEntitiesPositiveResponseDataTypedDict(TypedDict):
    next: Nullable[str]
    r"""Cursor string that can be passed to the `cursor` query parameter to get the next page. If this is `null`, then there are no more pages."""
    results: List[GetHrisStaffingEntitiesPositiveResponseResultTypedDict]


class GetHrisStaffingEntitiesPositiveResponseData(BaseModel):
    next: Nullable[str]
    r"""Cursor string that can be passed to the `cursor` query parameter to get the next page. If this is `null`, then there are no more pages."""

    results: List[GetHrisStaffingEntitiesPositiveResponseResult]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


class GetHrisStaffingEntitiesPositiveResponseTypedDict(TypedDict):
    data: GetHrisStaffingEntitiesPositiveResponseDataTypedDict
    status: Literal["success"]


class GetHrisStaffingEntitiesPositiveResponse(BaseModel):
    data: GetHrisStaffingEntitiesPositiveResponseData

    STATUS: Annotated[
        Annotated[Literal["success"], AfterValidator(validate_const("success"))],
        pydantic.Field(alias="status"),
    ] = "success"


try:
    GetHrisStaffingEntitiesPositiveResponse.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel
from typing_extensions import TypedDict


class PutIntegrationsIntegrationIDEnabledRequestBodyTypedDict(TypedDict):
    value: bool
    r"""The desired state of the integration (e.g., `true` for enabled, `false` for disabled)."""


class PutIntegrationsIntegrationIDEnabledRequestBody(BaseModel):
    value: bool
    r"""The desired state of the integration (e.g., `true` for enabled, `false` for disabled)."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Literal, Optional
from typing_extensions import NotRequired, TypedDict


PostConnectCreateLinkRequestBodyIntegrationCategory = Literal[
    "HRIS",
    "ATS",
    "ASSESSMENT",
    "LMS",
]
r"""Category of the integration you want your customer to create."""


IntegrationTool = Literal[
    "workday",
    "successfactors",
    "smartrecruiters",
    "factorial",
    "oraclerecruiting",
    "lever",
    "icims",
    "cornerstonetalentlink",
    "recruitee",
    "recruiterflow",
    "greenhouse",
    "greenhousejobboard",
    "teamtailor",
    "teamtailorjobboards",
    "ashby",
    "talentsoft",
    "talentsoftcustomer",
    "concludis",
    "talention",
    "piloga",
    "onlyfy",
    "personio",
    "ukgpro",
    "ukgready",
    "adpworkforcenow",
    "taleo",
    "rexx",
    "afas",
    "bamboohr",
    "bullhorn",
    "bullhornlogin",
    "workable",
    "jobvite",
    "fountain",
    "softgarden",
    "softgardenpartner",
    "pinpoint",
    "welcometothejungle",
    "dvinci",
    "dvinciadmin",
    "join",
    "sagehr",
    "traffit",
    "erecruiter",
    "abacusumantis",
    "umantis",
    "jobylon",
    "taleez",
    "hrworks",
    "otys",
    "zohorecruit",
    "ceipal",
    "eploy",
    "jobdiva",
    "careerplug",
    "perview",
    "eightfold",
    "paylocity",
    "paycor",
    "avature",
    "apploi",
    "phenom",
    "paradox",
    "heyrecruit",
    "recruhr",
    "recruitcrm",
    "jazzhr",
    "bite",
    "homerun",
    "mysolution",
    "carerix",
    "hroffice",
    "talentclue",
    "inrecruiting",
    "ubeeo",
    "connexys",
    "hr4you",
    "cornerstoneondemand",
    "zvooverecruit",
    "odoo",
    "comeet",
    "compleet",
    "compleetpitcher",
    "gem",
    "laura",
    "covetorest",
    "coveto",
    "crelate",
    "manatal",
    "avionte",
    "mhmhr",
    "asymbl",
    "breezyhr",
    "flatchr",
    "dayforce",
    "digitalrecruiters",
    "applicantstack",
    "reachmee",
    "talentadore",
    "sandbox",
    "guidecom",
    "spott",
    "loxo",
    "workdaycustomreport",
    "workdaycustomreportsftp",
    "payfitcustomer",
    "payfitpartner",
    "payfit",
    "employmenthero",
    "fourth",
    "kenjo",
    "heavenhr",
    "hibob",
    "cezannehr",
    "entraid",
    "azuread",
    "googleworkspace",
    "nmbrs",
    "deel",
    "remotecom",
    "iriscascade",
    "okta",
    "sagepeople",
    "humaans",
    "eurecia",
    "oraclehcm",
    "officient",
    "sesamehr",
    "charliehr",
    "abacus",
    "zohopeople",
    "gusto",
    "breathehr",
    "catalystone",
    "mirus",
    "alexishr",
    "simployer",
    "peple",
    "youserve",
    "hansalog",
    "lattice",
    "latticetalent",
    "hoorayhr",
    "trinet",
    "trinetpeo",
    "namely",
    "paycom",
    "insperity",
    "paychex",
    "rippling",
    "sapling",
    "peoplehr",
    "lucca",
    "zelt",
    "planday",
    "boondmanager",
    "haileyhr",
    "silae",
    "oysterhr",
    "kiwihr",
    "square",
    "perbilityhelix",
    "leapsome",
    "loket",
    "workforcecom",
    "peoplefirst",
    "sdworx",
    "itrent",
    "absenceio",
    "a3innuvanomina",
    "scim",
    "datevhr",
    "datev",
    "datevlug",
    "sympa",
    "youforce",
    "nibelis",
    "peoplexd",
    "sftp",
    "sftpfetch",
    "360learning",
    "talentlms",
    "udemy",
    "linkedinlearning",
]
r"""Pre-define a tool this integration link can be used for."""


PostConnectCreateLinkRequestBodyLanguage = Literal[
    "en",
    "de",
    "fr",
    "it",
    "es",
]
r"""Language of the connection flow UI."""


PostConnectCreateLinkRequestBodyLinkType = Literal[
    "EMBEDDED",
    "MAGIC_LINK",
]
r"""The type of link you want to create. `EMBEDDED` is for the [embedded flow](../guides/connect/embedded-flow) using the Kombo Connect SDK (these links are valid for 1 hour) and `MAGIC_LINK` is for [magic links](../guides/connect/magic-links) which you send out manually to customers (there are valid for 1 year).

This defaults to `EMBEDDED`, which is our recommended method of implementing the connection flow for a seamless user experience.
"""


class PostConnectCreateLinkRequestBodyTypedDict(TypedDict):
    end_user_email: str
    r"""The email of the user this link is meant for."""
    end_user_organization_name: str
    r"""The name of the user's organization."""
    end_user_origin_id: NotRequired[Nullable[str]]
    r"""The id the user/organization has in your own database."""
    remote_environment: NotRequired[Nullable[str]]
    r"""If the tool you want to connect offers different environments, you can specify which one you want to connect to here. If you don't specify this, we'll assume you want to use the production environment. Note that this can only be used if you've also specified a tool through `integration_tool`."""
    integration_category: NotRequired[
        PostConnectCreateLinkRequestBodyIntegrationCategory
    ]
    r"""Category of the integration you want your customer to create."""
    integration_tool: NotRequired[Nullable[IntegrationTool]]
    r"""Pre-define a tool this integration link can be used for."""
    language: NotRequired[Nullable[PostConnectCreateLinkRequestBodyLanguage]]
    r"""Language of the connection flow UI."""
    scope_config_id: NotRequired[Nullable[str]]
    r"""Specify a scope config that should be used for this integration. This is an advanced feature, only use it if you know what you're doing!"""
    enable_filtering: NotRequired[bool]
    r"""Enable the [filtering feature](https://docs.kombo.dev/other/filtering) for the integration. HRIS only."""
    enable_field_mapping: NotRequired[bool]
    r"""Enable the [field mapping feature](https://docs.kombo.dev/hris/features/setup-flow/introduction#field-mapping) for this integration."""
    link_type: NotRequired[PostConnectCreateLinkRequestBodyLinkType]
    r"""The type of link you want to create. `EMBEDDED` is for the [embedded flow](../guides/connect/embedded-flow) using the Kombo Connect SDK (these links are valid for 1 hour) and `MAGIC_LINK` is for [magic links](../guides/connect/magic-links) which you send out manually to customers (there are valid for 1 year).

    This defaults to `EMBEDDED`, which is our recommended method of implementing the connection flow for a seamless user experience.
    """


class PostConnectCreateLinkRequestBody(BaseModel):
    end_user_email: str
    r"""The email of the user this link is meant for."""

    end_user_organization_name: str
    r"""The name of the user's organization."""

    end_user_origin_id: OptionalNullable[str] = UNSET
    r"""The id the user/organization has in your own database."""

    remote_environment: OptionalNullable[str] = UNSET
    r"""If the tool you want to connect offers different environments, you can specify which one you want to connect to here. If you don't specify this, we'll assume you want to use the production environment. Note that this can only be used if you've also specified a tool through `integration_tool`."""

    integration_category: Optional[
        PostConnectCreateLinkRequestBodyIntegrationCategory
    ] = "HRIS"
    r"""Category of the integration you want your customer to create."""

    integration_tool: OptionalNullable[IntegrationTool] = UNSET
    r"""Pre-define a tool this integration link can be used for."""

    language: OptionalNullable[PostConnectCreateLinkRequestBodyLanguage] = "en"
    r"""Language of the connection flow UI."""

    scope_config_id: OptionalNullable[str] = UNSET
    r"""Specify a scope config that should be used for this integration. This is an advanced feature, only use it if you know what you're doing!"""

    enable_filtering: Optional[bool] = False
    r"""Enable the [filtering feature](https://docs.kombo.dev/other/filtering) for the integration. HRIS only."""

    enable_field_mapping: Optional[bool] = False
    r"""Enable the [field mapping feature](https://docs.kombo.dev/hris/features/setup-flow/introduction#field-mapping) for this integration."""

    link_type: Optional[PostConnectCreateLinkRequestBodyLinkType] = "EMBEDDED"
    r"""The type of link you want to create. `EMBEDDED` is for the [embedded flow](../guides/connect/embedded-flow) using the Kombo Connect SDK (these links are valid for 1 hour) and `MAGIC_LINK` is for [magic links](../guides/connect/magic-links) which you send out manually to customers (there are valid for 1 year).

    This defaults to `EMBEDDED`, which is our recommended method of implementing the connection flow for a seamless user experience.
    """

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "end_user_origin_id",
                "remote_environment",
                "integration_category",
                "integration_tool",
                "language",
                "scope_config_id",
                "enable_filtering",
                "enable_field_mapping",
                "link_type",
            ]
        )
        nullable_fields = set(
            [
                "end_user_origin_id",
                "remote_environment",
                "integration_tool",
                "language",
                "scope_config_id",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel
from kombo.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


class GetCheckAPIKeyPositiveResponseDataTypedDict(TypedDict):
    environment_id: str


class GetCheckAPIKeyPositiveResponseData(BaseModel):
    environment_id: str


class GetCheckAPIKeyPositiveResponseTypedDict(TypedDict):
    data: GetCheckAPIKeyPositiveResponseDataTypedDict
    status: Literal["success"]


class GetCheckAPIKeyPositiveResponse(BaseModel):
    data: GetCheckAPIKeyPositiveResponseData

    STATUS: Annotated[
        Annotated[Literal["success"], AfterValidator(validate_const("success"))],
        pydantic.Field(alias="status"),
    ] = "success"


try:
    GetCheckAPIKeyPositiveResponse.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel
from kombo.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import List, Literal
from typing_extensions import Annotated, TypedDict


class PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseDataTypedDict(
    TypedDict
):
    pass


class PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseData(BaseModel):
    pass


class PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseWarningTypedDict(
    TypedDict
):
    message: str


class PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseWarning(BaseModel):
    message: str


class PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseTypedDict(TypedDict):
    data: PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseDataTypedDict
    warnings: List[
        PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseWarningTypedDict
    ]
    r"""These are the interaction warnings that are shown in the dashboard. They are meant to provide debug information to you. We recommend logging them to the console."""
    status: Literal["success"]


class PutAssessmentOrdersAssessmentOrderIDResultPositiveResponse(BaseModel):
    data: PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseData

    warnings: List[PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseWarning]
    r"""These are the interaction warnings that are shown in the dashboard. They are meant to provide debug information to you. We recommend logging them to the console."""

    STATUS: Annotated[
        Annotated[Literal["success"], AfterValidator(validate_const("success"))],
        pydantic.Field(alias="status"),
    ] = "success"


try:
    PutAssessmentOrdersAssessmentOrderIDResultPositiveResponse.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .deleteintegrationsintegrationidrequestbody import (
    DeleteIntegrationsIntegrationIDRequestBody,
    DeleteIntegrationsIntegrationIDRequestBodyTypedDict,
)
from kombo.types import BaseModel
from kombo.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class DeleteIntegrationsIntegrationIDRequestTypedDict(TypedDict):
    integration_id: str
    r"""DELETE /integrations/:integration_id Parameter"""
    body: DeleteIntegrationsIntegrationIDRequestBodyTypedDict
    r"""DELETE /integrations/:integration_id Request body"""


class DeleteIntegrationsIntegrationIDRequest(BaseModel):
    integration_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""DELETE /integrations/:integration_id Parameter"""

    body: Annotated[
        DeleteIntegrationsIntegrationIDRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
    r"""DELETE /integrations/:integration_id Request body"""
